#!/usr/bin/env python

import libxml2dom
import calendar

# Borrowed from calendar, but with a non-global first weekday variable.

def monthcalendar(year, month, firstweekday=0):
    """Return a matrix representing a month's calendar.
       Each row represents a week; days outside this month are zero."""
    day1, ndays = calendar.monthrange(year, month)
    rows = []
    r7 = range(7)
    day = (firstweekday - day1 + 6) % 7 - 5   # for leading 0's in first week
    while day <= ndays:
        row = [0, 0, 0, 0, 0, 0, 0]
        for i in r7:
            if 1 <= day <= ndays: row[i] = day
            day = day + 1
        rows.append(row)
    return rows

# XML production functions.

def write_month_to_document(doc, root, year, month):
    weeks = monthcalendar(year, month)
    month_element = root.appendChild(doc.createElement("month"))
    month_element.setAttribute("number", str(month))
    month_element.setAttribute("year", str(year))
    for numbers in weeks:
        week_element = month_element.appendChild(doc.createElement("week"))
        for number in numbers:
            day_element = week_element.appendChild(doc.createElement("day"))
            if number != 0:
                day_element.setAttribute("date", "%04d%02d%02d" % (year, month, number))
                day_element.setAttribute("number", str(number))

def get_calendar_for_month(year, month):
    doc = libxml2dom.createDocument(None, "calendar", None)
    write_month_to_document(doc, doc.childNodes[-1], year, month)
    return doc

if __name__ == "__main__":
    import sys
    try:
        print get_calendar_for_month(int(sys.argv[1]), int(sys.argv[2])).toString()
    except (IndexError, ValueError):
        print "Please specify a year and a month (numeric, 1-12)."

# vim: tabstop=4 expandtab shiftwidth=4
